==> mauticGIT-Test-20251111_133203.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/a8/a8230cd7d56095433243ed5f8e76ce3b.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/FormBundle/ProgressiveProfiling/DisplayCounter.php */
class __TwigTemplate_1a6018287fc7ff2af4dd8e6c3ab9e5c5 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\FormBundle\\ProgressiveProfiling;

use Mautic\\FormBundle\\Entity\\Field;
use Mautic\\FormBundle\\Entity\\Form;

class DisplayCounter
{
    private int \$displayedFields = 0;

    private int \$alreadyAlwaysDisplayed = 0;

    public function __construct(
        private Form \$form
    ) {
    }

    public function increaseDisplayedFields(): void
    {
        ++\$this->displayedFields;
    }

    public function getDisplayFields(): int
    {
        return \$this->displayedFields;
    }

    public function increaseAlreadyAlwaysDisplayed(): void
    {
        ++\$this->alreadyAlwaysDisplayed;
    }

    public function getAlreadyAlwaysDisplayed(): int
    {
        return \$this->alreadyAlwaysDisplayed;
    }

    public function getAlwaysDisplayFields(): int
    {
        \$i= 0;
        /** @var Field \$field */
        foreach (\$this->form->getFields()->toArray() as \$field) {
            if (\$field->isAlwaysDisplay()) {
                ++\$i;
            }
        }

        return \$i;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/FormBundle/ProgressiveProfiling/DisplayCounter.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/FormBundle/ProgressiveProfiling/DisplayCounter.php", "/var/www/mautic-ktn/app/bundles/FormBundle/ProgressiveProfiling/DisplayCounter.php");
    }
}

==> mauticGIT-Test-20260119_091040.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/a8/a8230cd7d56095433243ed5f8e76ce3b.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/FormBundle/ProgressiveProfiling/DisplayCounter.php */
class __TwigTemplate_1a6018287fc7ff2af4dd8e6c3ab9e5c5 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\FormBundle\\ProgressiveProfiling;

use Mautic\\FormBundle\\Entity\\Field;
use Mautic\\FormBundle\\Entity\\Form;

class DisplayCounter
{
    private int \$displayedFields = 0;

    private int \$alreadyAlwaysDisplayed = 0;

    public function __construct(
        private Form \$form
    ) {
    }

    public function increaseDisplayedFields(): void
    {
        ++\$this->displayedFields;
    }

    public function getDisplayFields(): int
    {
        return \$this->displayedFields;
    }

    public function increaseAlreadyAlwaysDisplayed(): void
    {
        ++\$this->alreadyAlwaysDisplayed;
    }

    public function getAlreadyAlwaysDisplayed(): int
    {
        return \$this->alreadyAlwaysDisplayed;
    }

    public function getAlwaysDisplayFields(): int
    {
        \$i= 0;
        /** @var Field \$field */
        foreach (\$this->form->getFields()->toArray() as \$field) {
            if (\$field->isAlwaysDisplay()) {
                ++\$i;
            }
        }

        return \$i;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/FormBundle/ProgressiveProfiling/DisplayCounter.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/FormBundle/ProgressiveProfiling/DisplayCounter.php", "/var/www/html/mauticGIT-Test/app/bundles/FormBundle/ProgressiveProfiling/DisplayCounter.php");
    }
}
